dagger/dsl/current_module
Types
pub type Opts {
Opts(
include: option.Option(List(String)),
exclude: option.Option(List(String)),
gitignore: option.Option(Bool),
)
}
Constructors
-
Opts( include: option.Option(List(String)), exclude: option.Option(List(String)), gitignore: option.Option(Bool), )
Values
pub fn current_module() -> types.CurrentModule
pub fn dependencies(
parent: types.CurrentModule,
select select: fn(types.Module) -> List(types.Field),
client client: types.Client,
then handler: fn(Result(List(types.Module), types.QueryError)) -> a,
) -> a
The dependencies of the module.
pub fn generated_context_directory(
parent: types.CurrentModule,
) -> types.Directory
The generated files and directories made on top of the module source’s context directory.
pub fn generators(
parent: types.CurrentModule,
with with_fn: fn(Opts) -> Opts,
) -> types.GeneratorGroup
Return all generators defined by the module
pub fn id(parent: types.CurrentModule) -> types.CurrentModule
A unique identifier for this CurrentModule.
pub fn name(
parent: types.CurrentModule,
client client: types.Client,
then handler: fn(Result(String, types.QueryError)) -> a,
) -> a
The name of the module being executed in
pub fn source(parent: types.CurrentModule) -> types.Directory
The directory containing the module’s source code loaded into the engine (plus any generated code that may have been created).
pub fn workdir(
parent: types.CurrentModule,
path path: String,
with with_fn: fn(Opts) -> Opts,
) -> types.Directory
Load a directory from the module’s scratch working directory, including any changes that may have been made to it during module function execution.
pub fn workdir_file(
parent: types.CurrentModule,
path path: String,
) -> types.File
Load a file from the module’s scratch working directory, including any changes that may have been made to it during module function execution.Load a file from the module’s scratch working directory, including any changes that may have been made to it during module function execution.