dagger/dsl/enum_value_type_def

Values

pub fn deprecated(
  parent: types.EnumValueTypeDef,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

The reason this enum member is deprecated, if any.

pub fn description(
  parent: types.EnumValueTypeDef,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

A doc string for the enum member, if any.

pub fn id(
  parent: types.EnumValueTypeDef,
) -> types.EnumValueTypeDef

A unique identifier for this EnumValueTypeDef.

pub fn name(
  parent: types.EnumValueTypeDef,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

The name of the enum member.

pub fn source_map(
  parent: types.EnumValueTypeDef,
) -> types.SourceMap

The location of this enum member declaration.

pub fn value(
  parent: types.EnumValueTypeDef,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

The value of the enum member

Search Document