dagger/dsl/env

Types

pub type Opts {
  Opts(include: option.Option(List(String)))
}

Constructors

Values

pub fn check(parent: types.Env, name name: String) -> types.Check

Return the check with the given name from the installed modules. Must match exactly one check.

pub fn checks(
  parent: types.Env,
  with with_fn: fn(Opts) -> Opts,
) -> types.CheckGroup

Return all checks defined by the installed modules

pub fn env() -> types.Env
pub fn id(parent: types.Env) -> types.Env

A unique identifier for this Env.

pub fn include(opts: Opts, val: List(String)) -> Opts
pub fn input(
  parent: types.Env,
  name name: String,
) -> types.Binding

Retrieves an input binding by name

pub fn inputs(
  parent: types.Env,
  select select: fn(types.Binding) -> List(types.Field),
  client client: types.Client,
  then handler: fn(Result(List(types.Binding), types.QueryError)) -> a,
) -> a

Returns all input bindings provided to the environment

pub fn none(opts: Opts) -> Opts
pub fn output(
  parent: types.Env,
  name name: String,
) -> types.Binding

Retrieves an output binding by name

pub fn outputs(
  parent: types.Env,
  select select: fn(types.Binding) -> List(types.Field),
  client client: types.Client,
  then handler: fn(Result(List(types.Binding), types.QueryError)) -> a,
) -> a

Returns all declared output bindings for the environment

pub fn with_address_input(
  parent: types.Env,
  name name: String,
  value value: types.Address,
  description description: String,
) -> types.Env

Create or update a binding of type Address in the environment

pub fn with_address_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired Address output to be assigned in the environment

pub fn with_cache_volume_input(
  parent: types.Env,
  name name: String,
  value value: types.CacheVolume,
  description description: String,
) -> types.Env

Create or update a binding of type CacheVolume in the environment

pub fn with_cache_volume_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired CacheVolume output to be assigned in the environment

pub fn with_changeset_input(
  parent: types.Env,
  name name: String,
  value value: types.Changeset,
  description description: String,
) -> types.Env

Create or update a binding of type Changeset in the environment

pub fn with_changeset_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired Changeset output to be assigned in the environment

pub fn with_check_group_input(
  parent: types.Env,
  name name: String,
  value value: types.CheckGroup,
  description description: String,
) -> types.Env

Create or update a binding of type CheckGroup in the environment

pub fn with_check_group_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired CheckGroup output to be assigned in the environment

pub fn with_check_input(
  parent: types.Env,
  name name: String,
  value value: types.Check,
  description description: String,
) -> types.Env

Create or update a binding of type Check in the environment

pub fn with_check_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired Check output to be assigned in the environment

pub fn with_cloud_input(
  parent: types.Env,
  name name: String,
  value value: types.Cloud,
  description description: String,
) -> types.Env

Create or update a binding of type Cloud in the environment

pub fn with_cloud_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired Cloud output to be assigned in the environment

pub fn with_container_input(
  parent: types.Env,
  name name: String,
  value value: types.Container,
  description description: String,
) -> types.Env

Create or update a binding of type Container in the environment

pub fn with_container_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired Container output to be assigned in the environment

pub fn with_current_module(parent: types.Env) -> types.Env

Installs the current module into the environment, exposing its functions to the model Contextual path arguments will be populated using the environment’s workspace.

pub fn with_directory_input(
  parent: types.Env,
  name name: String,
  value value: types.Directory,
  description description: String,
) -> types.Env

Create or update a binding of type Directory in the environment

pub fn with_directory_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired Directory output to be assigned in the environment

pub fn with_env_file_input(
  parent: types.Env,
  name name: String,
  value value: types.EnvFile,
  description description: String,
) -> types.Env

Create or update a binding of type EnvFile in the environment

pub fn with_env_file_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired EnvFile output to be assigned in the environment

pub fn with_env_input(
  parent: types.Env,
  name name: String,
  value value: types.Env,
  description description: String,
) -> types.Env

Create or update a binding of type Env in the environment

pub fn with_env_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired Env output to be assigned in the environment

pub fn with_file_input(
  parent: types.Env,
  name name: String,
  value value: types.File,
  description description: String,
) -> types.Env

Create or update a binding of type File in the environment

pub fn with_file_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired File output to be assigned in the environment

pub fn with_generator_group_input(
  parent: types.Env,
  name name: String,
  value value: types.GeneratorGroup,
  description description: String,
) -> types.Env

Create or update a binding of type GeneratorGroup in the environment

pub fn with_generator_group_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired GeneratorGroup output to be assigned in the environment

pub fn with_generator_input(
  parent: types.Env,
  name name: String,
  value value: types.Generator,
  description description: String,
) -> types.Env

Create or update a binding of type Generator in the environment

pub fn with_generator_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired Generator output to be assigned in the environment

pub fn with_git_ref_input(
  parent: types.Env,
  name name: String,
  value value: types.GitRef,
  description description: String,
) -> types.Env

Create or update a binding of type GitRef in the environment

pub fn with_git_ref_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired GitRef output to be assigned in the environment

pub fn with_git_repository_input(
  parent: types.Env,
  name name: String,
  value value: types.GitRepository,
  description description: String,
) -> types.Env

Create or update a binding of type GitRepository in the environment

pub fn with_git_repository_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired GitRepository output to be assigned in the environment

pub fn with_j_s_o_n_value_input(
  parent: types.Env,
  name name: String,
  value value: types.JSONValue,
  description description: String,
) -> types.Env

Create or update a binding of type JSONValue in the environment

pub fn with_j_s_o_n_value_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired JSONValue output to be assigned in the environment

pub fn with_main_module(
  parent: types.Env,
  module module: types.Module,
) -> types.Env

Sets the main module for this environment (the project being worked on) Contextual path arguments will be populated using the environment’s workspace.

pub fn with_module_config_client_input(
  parent: types.Env,
  name name: String,
  value value: types.ModuleConfigClient,
  description description: String,
) -> types.Env

Create or update a binding of type ModuleConfigClient in the environment

pub fn with_module_config_client_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired ModuleConfigClient output to be assigned in the environment

pub fn with_module_input(
  parent: types.Env,
  name name: String,
  value value: types.Module,
  description description: String,
) -> types.Env

Create or update a binding of type Module in the environment

pub fn with_module_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired Module output to be assigned in the environment

pub fn with_module_source_input(
  parent: types.Env,
  name name: String,
  value value: types.ModuleSource,
  description description: String,
) -> types.Env

Create or update a binding of type ModuleSource in the environment

pub fn with_module_source_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired ModuleSource output to be assigned in the environment

pub fn with_search_result_input(
  parent: types.Env,
  name name: String,
  value value: types.SearchResult,
  description description: String,
) -> types.Env

Create or update a binding of type SearchResult in the environment

pub fn with_search_result_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired SearchResult output to be assigned in the environment

pub fn with_search_submatch_input(
  parent: types.Env,
  name name: String,
  value value: types.SearchSubmatch,
  description description: String,
) -> types.Env

Create or update a binding of type SearchSubmatch in the environment

pub fn with_search_submatch_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired SearchSubmatch output to be assigned in the environment

pub fn with_secret_input(
  parent: types.Env,
  name name: String,
  value value: types.Secret,
  description description: String,
) -> types.Env

Create or update a binding of type Secret in the environment

pub fn with_secret_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired Secret output to be assigned in the environment

pub fn with_service_input(
  parent: types.Env,
  name name: String,
  value value: types.Service,
  description description: String,
) -> types.Env

Create or update a binding of type Service in the environment

pub fn with_service_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired Service output to be assigned in the environment

pub fn with_socket_input(
  parent: types.Env,
  name name: String,
  value value: types.Socket,
  description description: String,
) -> types.Env

Create or update a binding of type Socket in the environment

pub fn with_socket_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired Socket output to be assigned in the environment

pub fn with_stat_input(
  parent: types.Env,
  name name: String,
  value value: types.Stat,
  description description: String,
) -> types.Env

Create or update a binding of type Stat in the environment

pub fn with_stat_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declare a desired Stat output to be assigned in the environment

pub fn with_string_input(
  parent: types.Env,
  name name: String,
  value value: String,
  description description: String,
) -> types.Env

Provides a string input binding to the environment

pub fn with_string_output(
  parent: types.Env,
  name name: String,
  description description: String,
) -> types.Env

Declares a desired string output binding

pub fn with_workspace(
  parent: types.Env,
  workspace workspace: types.Directory,
) -> types.Env

Returns a new environment with the provided workspace

pub fn without_outputs(parent: types.Env) -> types.Env

Returns a new environment without any outputs

pub fn workspace(parent: types.Env) -> types.Directory
Search Document