dagger/dsl/function_arg
Values
pub fn default_address(
parent: types.FunctionArg,
client client: types.Client,
then handler: fn(Result(String, types.QueryError)) -> a,
) -> a
Only applies to arguments of type Container. If the argument is not set, load it from the given address (e.g. alpine:latest)
pub fn default_path(
parent: types.FunctionArg,
client client: types.Client,
then handler: fn(Result(String, types.QueryError)) -> a,
) -> a
Only applies to arguments of type File or Directory. If the argument is not set, load it from the given path in the context directory
pub fn default_value(
parent: types.FunctionArg,
client client: types.Client,
then handler: fn(Result(String, types.QueryError)) -> a,
) -> a
A default value to use for this argument when not explicitly set by the caller, if any.
pub fn deprecated(
parent: types.FunctionArg,
client client: types.Client,
then handler: fn(Result(String, types.QueryError)) -> a,
) -> a
The reason this function is deprecated, if any.
pub fn description(
parent: types.FunctionArg,
client client: types.Client,
then handler: fn(Result(String, types.QueryError)) -> a,
) -> a
A doc string for the argument, if any.
pub fn function_arg(
id id: types.FunctionArg,
) -> types.FunctionArg
pub fn id(parent: types.FunctionArg) -> types.FunctionArg
A unique identifier for this FunctionArg.
pub fn ignore(
parent: types.FunctionArg,
client client: types.Client,
then handler: fn(Result(List(String), types.QueryError)) -> a,
) -> a
Only applies to arguments of type Directory. The ignore patterns are applied to the input directory, and matching entries are filtered out, in a cache-efficient manner.
pub fn name(
parent: types.FunctionArg,
client client: types.Client,
then handler: fn(Result(String, types.QueryError)) -> a,
) -> a
The name of the argument in lowerCamelCase format.
pub fn source_map(parent: types.FunctionArg) -> types.SourceMap
The location of this arg declaration.