dagger/dsl/function_call

Values

pub fn function_call() -> types.FunctionCall
pub fn function_call_arg_value_id(
  parent: types.FunctionCallArgValue,
) -> types.FunctionCallArgValue

A unique identifier for this FunctionCallArgValue.

pub fn function_call_arg_value_name(
  parent: types.FunctionCallArgValue,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

The name of the argument.

pub fn function_call_id(
  parent: types.FunctionCall,
) -> types.FunctionCall

A unique identifier for this FunctionCall.

pub fn function_call_name(
  parent: types.FunctionCall,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

The name of the function being called.

pub fn input_args(
  parent: types.FunctionCall,
  select select: fn(types.FunctionCallArgValue) -> List(
    types.Field,
  ),
  client client: types.Client,
  then handler: fn(
    Result(List(types.FunctionCallArgValue), types.QueryError),
  ) -> a,
) -> a

The argument values the function is being invoked with.

pub fn parent(
  parent: types.FunctionCall,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

The value of the parent object of the function being called. If the function is top-level to the module, this is always an empty object.

pub fn parent_name(
  parent: types.FunctionCall,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

The name of the parent object of the function being called. If the function is top-level to the module, this is the name of the module.

pub fn return_error(
  parent: types.FunctionCall,
  error error: types.Error,
  client client: types.Client,
  then handler: fn(Result(Nil, types.QueryError)) -> a,
) -> a

Return an error from the function.

pub fn return_value(
  parent: types.FunctionCall,
  value value: String,
  client client: types.Client,
  then handler: fn(Result(Nil, types.QueryError)) -> a,
) -> a

Set the return value of the function call to the provided value.

pub fn value(
  parent: types.FunctionCallArgValue,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

The value of the argument represented as a JSON serialized string.

Search Document