dagger/dsl/generator

Values

pub fn changes(parent: types.Generator) -> types.Changeset

The generated changeset

pub fn completed(
  parent: types.Generator,
  client client: types.Client,
  then handler: fn(Result(Bool, types.QueryError)) -> a,
) -> a

Whether the generator complete

pub fn description(
  parent: types.Generator,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

Return the description of the generator

pub fn id(parent: types.Generator) -> types.Generator

A unique identifier for this Generator.

pub fn is_empty(
  parent: types.Generator,
  client client: types.Client,
  then handler: fn(Result(Bool, types.QueryError)) -> a,
) -> a

Wether changeset from the generator execution is empty or not

pub fn name(
  parent: types.Generator,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

Return the fully qualified name of the generator

pub fn original_module(parent: types.Generator) -> types.Module

The original module in which the generator has been defined

pub fn path(
  parent: types.Generator,
  client client: types.Client,
  then handler: fn(Result(List(String), types.QueryError)) -> a,
) -> a

The path of the generator within its module

pub fn run(parent: types.Generator) -> types.Generator

Execute the generator

Search Document