dagger/dsl/git

Types

pub type ForGitRepository
pub type ForTree
pub opaque type Opts(tag_)

Values

pub fn branch(
  parent: types.GitRepository,
  name name: String,
) -> types.GitRef

Returns details of a branch.

pub fn branches(
  parent: types.GitRepository,
  with with_fn: fn(Opts(a)) -> Opts(a),
  client client: types.Client,
  then handler: fn(Result(List(String), types.QueryError)) -> a,
) -> a

branches that match any of the given glob patterns.

pub fn common_ancestor(
  parent: types.GitRef,
  other other: types.GitRef,
) -> types.GitRef

Find the best common ancestor between this ref and another ref.

pub fn git_ref(id id: types.GitRef) -> types.GitRef
pub fn git_repository(
  url url: String,
  with with_fn: fn(Opts(ForGitRepository)) -> Opts(
    ForGitRepository,
  ),
) -> types.GitRepository
pub fn head(parent: types.GitRepository) -> types.GitRef

Returns details for HEAD.

pub fn latest_version(
  parent: types.GitRepository,
) -> types.GitRef

Returns details for the latest semver tag.

pub fn none(opts: Opts(a)) -> Opts(a)
pub fn opt_depth(opts: Opts(ForTree), val: Int) -> Opts(ForTree)
pub fn opt_discard_git_dir(
  opts: Opts(ForTree),
  val: Bool,
) -> Opts(ForTree)
pub fn opt_experimental_service_host(
  opts: Opts(ForGitRepository),
  val: types.Service,
) -> Opts(ForGitRepository)
pub fn opt_http_auth_header(
  opts: Opts(ForGitRepository),
  val: types.Secret,
) -> Opts(ForGitRepository)
pub fn opt_http_auth_token(
  opts: Opts(ForGitRepository),
  val: types.Secret,
) -> Opts(ForGitRepository)
pub fn opt_http_auth_username(
  opts: Opts(ForGitRepository),
  val: String,
) -> Opts(ForGitRepository)
pub fn opt_patterns(opts: Opts(a), val: List(String)) -> Opts(a)
pub fn opt_ssh_auth_socket(
  opts: Opts(ForGitRepository),
  val: types.Socket,
) -> Opts(ForGitRepository)
pub fn opt_ssh_known_hosts(
  opts: Opts(ForGitRepository),
  val: String,
) -> Opts(ForGitRepository)
pub fn ref_commit(
  parent: types.GitRef,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

The resolved commit id at this ref.

pub fn ref_id(parent: types.GitRef) -> types.GitRef

A unique identifier for this GitRef.

pub fn ref_ref(
  parent: types.GitRef,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

The resolved ref name at this ref.

pub fn repository_commit(
  parent: types.GitRepository,
  id id: String,
) -> types.GitRef

Returns details of a commit.

pub fn repository_id(
  parent: types.GitRepository,
) -> types.GitRepository

A unique identifier for this GitRepository.

pub fn repository_ref(
  parent: types.GitRepository,
  name name: String,
) -> types.GitRef

Returns details of a ref.

pub fn tag(
  parent: types.GitRepository,
  name name: String,
) -> types.GitRef

Returns details of a tag.

pub fn tags(
  parent: types.GitRepository,
  with with_fn: fn(Opts(a)) -> Opts(a),
  client client: types.Client,
  then handler: fn(Result(List(String), types.QueryError)) -> a,
) -> a

tags that match any of the given glob patterns.

pub fn tree(
  parent: types.GitRef,
  with with_fn: fn(Opts(ForTree)) -> Opts(ForTree),
) -> types.Directory

The filesystem tree at this ref.

pub fn uncommitted(
  parent: types.GitRepository,
) -> types.Changeset

Returns the changeset of uncommitted changes in the git repository.

pub fn url(
  parent: types.GitRepository,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

The URL of the git repository.

Search Document