dagger/dsl/s_d_k_config

Values

pub fn debug(
  parent: types.SDKConfig,
  client client: types.Client,
  then handler: fn(Result(Bool, types.QueryError)) -> a,
) -> a

Whether to start the SDK runtime in debug mode with an interactive terminal.

pub fn id(parent: types.SDKConfig) -> types.SDKConfig

A unique identifier for this SDKConfig.

pub fn source(
  parent: types.SDKConfig,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

Source of the SDK. Either a name of a builtin SDK or a module source ref string pointing to the SDK’s implementation.

Search Document