dagger/dsl/engine_cache_entry
Values
pub fn actively_used(
parent: types.EngineCacheEntry,
client client: types.Client,
then handler: fn(Result(Bool, types.QueryError)) -> a,
) -> a
Whether the cache entry is actively being used.
pub fn created_time_unix_nano(
parent: types.EngineCacheEntry,
client client: types.Client,
then handler: fn(Result(Int, types.QueryError)) -> a,
) -> a
The time the cache entry was created, in Unix nanoseconds.
pub fn description(
parent: types.EngineCacheEntry,
client client: types.Client,
then handler: fn(Result(String, types.QueryError)) -> a,
) -> a
The description of the cache entry.
pub fn disk_space_bytes(
parent: types.EngineCacheEntry,
client client: types.Client,
then handler: fn(Result(Int, types.QueryError)) -> a,
) -> a
The disk space used by the cache entry.
pub fn engine_cache_entry(
id id: types.EngineCacheEntry,
) -> types.EngineCacheEntry
pub fn id(
parent: types.EngineCacheEntry,
) -> types.EngineCacheEntry
A unique identifier for this EngineCacheEntry.
pub fn most_recent_use_time_unix_nano(
parent: types.EngineCacheEntry,
client client: types.Client,
then handler: fn(Result(Int, types.QueryError)) -> a,
) -> a
The most recent time the cache entry was used, in Unix nanoseconds.