dagger/dsl/generated_code

Values

pub fn code(parent: types.GeneratedCode) -> types.Directory

The directory containing the generated code.

pub fn generated_code(
  code code: types.Directory,
) -> types.GeneratedCode
pub fn id(parent: types.GeneratedCode) -> types.GeneratedCode

A unique identifier for this GeneratedCode.

pub fn vcs_generated_paths(
  parent: types.GeneratedCode,
  client client: types.Client,
  then handler: fn(Result(List(String), types.QueryError)) -> a,
) -> a

List of paths to mark generated in version control (i.e. .gitattributes).

pub fn vcs_ignored_paths(
  parent: types.GeneratedCode,
  client client: types.Client,
  then handler: fn(Result(List(String), types.QueryError)) -> a,
) -> a

List of paths to ignore in version control (i.e. .gitignore).

pub fn with_v_c_s_generated_paths(
  parent: types.GeneratedCode,
  paths paths: List(String),
) -> types.GeneratedCode

Set the list of paths to mark generated in version control.

pub fn with_v_c_s_ignored_paths(
  parent: types.GeneratedCode,
  paths paths: List(String),
) -> types.GeneratedCode

Set the list of paths to ignore in version control.

Search Document