dagger/dsl/generator_group
Types
pub type Opts {
Opts(on_conflict: option.Option(types.ChangesetsMergeConflict))
}
Constructors
-
Opts(on_conflict: option.Option(types.ChangesetsMergeConflict))
Values
pub fn changes(
parent: types.GeneratorGroup,
with with_fn: fn(Opts) -> Opts,
) -> types.Changeset
The combined changes from the generators execution If any conflict occurs, for instance if the same file is modified by multiple generators, or if a file is both modified and deleted, an error is raised and the merge of the changesets will failed. Set ‘continueOnConflicts’ flag to force to merge the changes in a ‘last write wins’ strategy.
pub fn generator_group(
id id: types.GeneratorGroup,
) -> types.GeneratorGroup
pub fn id(parent: types.GeneratorGroup) -> types.GeneratorGroup
A unique identifier for this GeneratorGroup.
pub fn is_empty(
parent: types.GeneratorGroup,
client client: types.Client,
then handler: fn(Result(Bool, types.QueryError)) -> a,
) -> a
Whether the generated changeset is empty or not
pub fn list(
parent: types.GeneratorGroup,
select select: fn(types.Generator) -> List(types.Field),
client client: types.Client,
then handler: fn(
Result(List(types.Generator), types.QueryError),
) -> a,
) -> a
Return a list of individual generators and their details
pub fn on_conflict(
opts: Opts,
val: types.ChangesetsMergeConflict,
) -> Opts
pub fn run(parent: types.GeneratorGroup) -> types.GeneratorGroup
Execute all selected generators