dagger/dsl/git

Types

pub type Opts {
  Opts(
    ssh_known_hosts: option.Option(String),
    ssh_auth_socket: option.Option(types.Socket),
    http_auth_username: option.Option(String),
    http_auth_token: option.Option(types.Secret),
    http_auth_header: option.Option(types.Secret),
    experimental_service_host: option.Option(types.Service),
    patterns: option.Option(List(String)),
    discard_git_dir: option.Option(Bool),
    depth: option.Option(Int),
  )
}

Constructors

Values

pub fn branch(
  parent: types.GitRepository,
  name name: String,
) -> types.GitRef

Returns details of a branch.

pub fn branches(
  parent: types.GitRepository,
  with with_fn: fn(Opts) -> Opts,
  client client: types.Client,
  then handler: fn(Result(List(String), types.QueryError)) -> a,
) -> a

branches that match any of the given glob patterns.

pub fn common_ancestor(
  parent: types.GitRef,
  other other: types.GitRef,
) -> types.GitRef

Find the best common ancestor between this ref and another ref.

pub fn depth(opts: Opts, val: Int) -> Opts
pub fn discard_git_dir(opts: Opts, val: Bool) -> Opts
pub fn experimental_service_host(
  opts: Opts,
  val: types.Service,
) -> Opts
pub fn git_ref(id id: types.GitRef) -> types.GitRef
pub fn git_repository(
  url url: String,
  with with_fn: fn(Opts) -> Opts,
) -> types.GitRepository
pub fn head(parent: types.GitRepository) -> types.GitRef

Returns details for HEAD.

pub fn http_auth_header(opts: Opts, val: types.Secret) -> Opts
pub fn http_auth_token(opts: Opts, val: types.Secret) -> Opts
pub fn http_auth_username(opts: Opts, val: String) -> Opts
pub fn latest_version(
  parent: types.GitRepository,
) -> types.GitRef

Returns details for the latest semver tag.

pub fn none(opts: Opts) -> Opts
pub fn patterns(opts: Opts, val: List(String)) -> Opts
pub fn ref_commit(
  parent: types.GitRef,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

The resolved commit id at this ref.

pub fn ref_id(parent: types.GitRef) -> types.GitRef

A unique identifier for this GitRef.

pub fn ref_ref(
  parent: types.GitRef,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

The resolved ref name at this ref.

pub fn repository_commit(
  parent: types.GitRepository,
  id id: String,
) -> types.GitRef

Returns details of a commit.

pub fn repository_id(
  parent: types.GitRepository,
) -> types.GitRepository

A unique identifier for this GitRepository.

pub fn repository_ref(
  parent: types.GitRepository,
  name name: String,
) -> types.GitRef

Returns details of a ref.

pub fn ssh_auth_socket(opts: Opts, val: types.Socket) -> Opts
pub fn ssh_known_hosts(opts: Opts, val: String) -> Opts
pub fn tag(
  parent: types.GitRepository,
  name name: String,
) -> types.GitRef

Returns details of a tag.

pub fn tags(
  parent: types.GitRepository,
  with with_fn: fn(Opts) -> Opts,
  client client: types.Client,
  then handler: fn(Result(List(String), types.QueryError)) -> a,
) -> a

tags that match any of the given glob patterns.

pub fn tree(
  parent: types.GitRef,
  with with_fn: fn(Opts) -> Opts,
) -> types.Directory

The filesystem tree at this ref.

pub fn uncommitted(
  parent: types.GitRepository,
) -> types.Changeset

Returns the changeset of uncommitted changes in the git repository.

pub fn url(
  parent: types.GitRepository,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

The URL of the git repository.

Search Document