dagger/dsl/host

Types

pub type ForDirectory
pub type ForService
pub type ForTunnel
pub opaque type Opts(tag_)

Values

pub fn container_image(
  parent: types.Host,
  name name: String,
) -> types.Container

Accesses a container image on the host.

pub fn directory(
  parent: types.Host,
  path path: String,
  with with_fn: fn(Opts(ForDirectory)) -> Opts(ForDirectory),
) -> types.Directory

Accesses a directory on the host.

pub fn file(
  parent: types.Host,
  path path: String,
  with with_fn: fn(Opts(a)) -> Opts(a),
) -> types.File

Accesses a file on the host.

pub fn find_up(
  parent: types.Host,
  name name: String,
  with with_fn: fn(Opts(a)) -> Opts(a),
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

Search for a file or directory by walking up the tree from system workdir. Return its relative path. If no match, return null

pub fn host() -> types.Host
pub fn id(parent: types.Host) -> types.Host

A unique identifier for this Host.

pub fn none(opts: Opts(a)) -> Opts(a)
pub fn opt_exclude(
  opts: Opts(ForDirectory),
  val: List(String),
) -> Opts(ForDirectory)
pub fn opt_gitignore(
  opts: Opts(ForDirectory),
  val: Bool,
) -> Opts(ForDirectory)
pub fn opt_host(
  opts: Opts(ForService),
  val: String,
) -> Opts(ForService)
pub fn opt_include(
  opts: Opts(ForDirectory),
  val: List(String),
) -> Opts(ForDirectory)
pub fn opt_native(
  opts: Opts(ForTunnel),
  val: Bool,
) -> Opts(ForTunnel)
pub fn opt_no_cache(opts: Opts(a), val: Bool) -> Opts(a)
pub fn opt_ports(
  opts: Opts(ForTunnel),
  val: List(types.PortForward),
) -> Opts(ForTunnel)
pub fn service(
  parent: types.Host,
  ports ports: List(types.PortForward),
  with with_fn: fn(Opts(ForService)) -> Opts(ForService),
) -> types.Service

Creates a service that forwards traffic to a specified address via the host.

pub fn tunnel(
  parent: types.Host,
  service service: types.Service,
  with with_fn: fn(Opts(ForTunnel)) -> Opts(ForTunnel),
) -> types.Service

Creates a tunnel that forwards traffic from the host to a service.

pub fn unix_socket(
  parent: types.Host,
  path path: String,
) -> types.Socket

Accesses a Unix socket on the host.

Search Document