dagger/dsl/host

Types

pub type Opts {
  Opts(
    exclude: option.Option(List(String)),
    include: option.Option(List(String)),
    no_cache: option.Option(Bool),
    gitignore: option.Option(Bool),
    host: option.Option(String),
    native: option.Option(Bool),
    ports: option.Option(List(types.PortForward)),
  )
}

Constructors

Values

pub fn container_image(
  parent: types.Host,
  name name: String,
) -> types.Container

Accesses a container image on the host.

pub fn directory(
  parent: types.Host,
  path path: String,
  with with_fn: fn(Opts) -> Opts,
) -> types.Directory

Accesses a directory on the host.

pub fn exclude(opts: Opts, val: List(String)) -> Opts
pub fn file(
  parent: types.Host,
  path path: String,
  with with_fn: fn(Opts) -> Opts,
) -> types.File

Accesses a file on the host.

pub fn find_up(
  parent: types.Host,
  name name: String,
  with with_fn: fn(Opts) -> Opts,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

Search for a file or directory by walking up the tree from system workdir. Return its relative path. If no match, return null

pub fn gitignore(opts: Opts, val: Bool) -> Opts
pub fn host() -> types.Host
pub fn id(parent: types.Host) -> types.Host

A unique identifier for this Host.

pub fn include(opts: Opts, val: List(String)) -> Opts
pub fn native(opts: Opts, val: Bool) -> Opts
pub fn no_cache(opts: Opts, val: Bool) -> Opts
pub fn none(opts: Opts) -> Opts
pub fn opt_host(opts: Opts, val: String) -> Opts
pub fn ports(opts: Opts, val: List(types.PortForward)) -> Opts
pub fn service(
  parent: types.Host,
  ports ports: List(types.PortForward),
  with with_fn: fn(Opts) -> Opts,
) -> types.Service

Creates a service that forwards traffic to a specified address via the host.

pub fn tunnel(
  parent: types.Host,
  service service: types.Service,
  with with_fn: fn(Opts) -> Opts,
) -> types.Service

Creates a tunnel that forwards traffic from the host to a service.

pub fn unix_socket(
  parent: types.Host,
  path path: String,
) -> types.Socket

Accesses a Unix socket on the host.

Search Document