dagger/dsl/object_type_def

Values

pub fn constructor(parent: types.ObjectTypeDef) -> types.Function

The function used to construct new instances of this object, if any

pub fn deprecated(
  parent: types.ObjectTypeDef,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

The reason this enum member is deprecated, if any.

pub fn description(
  parent: types.ObjectTypeDef,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

The doc string for the object, if any.

pub fn fields(
  parent: types.ObjectTypeDef,
  select select: fn(types.FieldTypeDef) -> List(types.Field),
  client client: types.Client,
  then handler: fn(
    Result(List(types.FieldTypeDef), types.QueryError),
  ) -> a,
) -> a

Static fields defined on this object, if any.

pub fn functions(
  parent: types.ObjectTypeDef,
  select select: fn(types.Function) -> List(types.Field),
  client client: types.Client,
  then handler: fn(Result(List(types.Function), types.QueryError)) -> a,
) -> a

Functions defined on this object, if any.

pub fn id(parent: types.ObjectTypeDef) -> types.ObjectTypeDef

A unique identifier for this ObjectTypeDef.

pub fn name(
  parent: types.ObjectTypeDef,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

The name of the object.

pub fn source_map(parent: types.ObjectTypeDef) -> types.SourceMap

The location of this object declaration.

pub fn source_module_name(
  parent: types.ObjectTypeDef,
  client client: types.Client,
  then handler: fn(Result(String, types.QueryError)) -> a,
) -> a

If this ObjectTypeDef is associated with a Module, the name of the module. Unset otherwise.

Search Document